diff src/video/riscos/SDL_riscosvideo.c @ 1035:974ba6ae0fa3

Date: Wed, 26 Jan 2005 13:37:09 GMT From: Peter Naulls Subject: RISC OS SDL Patches Sam, I've attached a diff of the latest changes to libSDL for RISC OS support. These changes are by Alan Buckley and myself. The most significant of these are: Optimised assembler blit rountines - I've attached the file src/video/riscos/SDL_riscosASM.s which is needed for this. Move to using /dev/dsp instead of its own audio implementation. This means that src/audio/riscos/SDL_drenderer.c should be removed Typo fixes. Mainly correct spelling of "RISC OS", but some from elsewhere too.
author Sam Lantinga <slouken@libsdl.org>
date Sat, 12 Feb 2005 18:01:31 +0000
parents b8d311d90021
children d90b362628ea
line wrap: on
line diff
--- a/src/video/riscos/SDL_riscosvideo.c	Sat Jan 29 09:58:40 2005 +0000
+++ b/src/video/riscos/SDL_riscosvideo.c	Sat Feb 12 18:01:31 2005 +0000
@@ -21,10 +21,10 @@
 */
 
 /*
-     File added by Alan Buckley (alan_baa@hotmail.com) for RISCOS compatability
+     File added by Alan Buckley (alan_baa@hotmail.com) for RISC OS compatability
 	 23 March 2003
 
-     Implements RISCOS display device management.
+     Implements RISC OS display device management.
 	 Routines for full screen and wimp modes are split
 	 into other source files.
 */
@@ -83,7 +83,7 @@
 static void RISCOS_UnlockHWSurface(_THIS, SDL_Surface *surface);
 static void RISCOS_FreeHWSurface(_THIS, SDL_Surface *surface);
 
 /* RISCOS driver bootstrap functions */
 
 static int RISCOS_Available(void)
 {
@@ -150,16 +150,11 @@
 	/* Set other entries for fullscreen mode */
 	FULLSCREEN_SetDeviceMode(device);
 
-/* Turn off unixlib file name translation - we hope people have initialised
-   the video system before they try to read any files */
-/*        __riscosify_control = __RISCOSIFY_NO_PROCESS;
-*//* We may be able to eventually replace our processing of filenames with the correct flags above*/
-
 	return device;
 }
 
 VideoBootStrap RISCOS_bootstrap = {
-	RISCOSVID_DRIVER_NAME, "RISCOS video driver",
+	RISCOSVID_DRIVER_NAME, "RISC OS video driver",
 	RISCOS_Available, RISCOS_CreateDevice
 };
@@ -83,7 +83,7 @@
 static void RISCOS_FreeHWSurface(_THIS, SDL_Surface *surface);
 
-/* RISCOS driver bootstrap functions */
+/* RISC OS driver bootstrap functions */
 
 static int RISCOS_Available(void)